@@ -97,3 +97,9 @@ class ReportType(str, Enum):
     GET_VENDOR_INVENTORY_HEALTH_AND_PLANNING_REPORT = 'GET_VENDOR_INVENTORY_HEALTH_AND_PLANNING_REPORT'
     GET_VENDOR_DEMAND_FORECAST_REPORT = 'GET_VENDOR_DEMAND_FORECAST_REPORT'
     GET_PROMOTION_PERFORMANCE_REPORT = 'GET_PROMOTION_PERFORMANCE_REPORT'
+    GET_BRAND_ANALYTICS_MARKET_BASKET_REPORT = 'GET_BRAND_ANALYTICS_MARKET_BASKET_REPORT'
+    GET_BRAND_ANALYTICS_REPEAT_PURCHASE_REPORT = 'GET_BRAND_ANALYTICS_REPEAT_PURCHASE_REPORT'
+    GET_BRAND_ANALYTICS_ALTERNATE_PURCHASE_REPORT = 'GET_BRAND_ANALYTICS_ALTERNATE_PURCHASE_REPORT'
+    GET_BRAND_ANALYTICS_ITEM_COMPARISON_REPORT = 'GET_BRAND_ANALYTICS_ITEM_COMPARISON_REPORT'
+    GET_VENDOR_NET_PURE_PRODUCT_MARGIN_REPORT = 'GET_VENDOR_NET_PURE_PRODUCT_MARGIN_REPORT'
+    GET_MERCHANTS_LISTINGS_FYP_REPORT = 'GET_MERCHANTS_LISTINGS_FYP_REPORT'
